Supporting Modules
==================

The following modules were written to support the creation of
fontFeatures plugins.

.. automodule:: fontFeatures.shaperLib
	:members:

.. automodule:: fontFeatures.pathUtils
	:members:
